==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/my_publishing.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_my.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_publish_blog_item'] = 				"Published journals";
$lang['hdr_publish_forum'] =		 			"Published discussion posts";
$lang['hdr_poll_participation'] = 				"Poll participation";
$lang['hdr_publish_library'] = 					"Published library documents";
$lang['hdr_publish_shouts'] = 					"Published shouts";


//ERRORS
$lang['err_no_blogs'] = 						"Sorry, you have no blog contents.";
$lang['err_no_library'] = 						"Sorry, you have no library documents.";
$lang['err_no_poll_participation'] =			"Sorry, you have not voted.";
$lang['err_no_shouts'] = 						"Sorry, no shouts.";
$lang['err_no_forum'] = 						"Sorry, you have no discussion posts.";


//BODY
$lang['txt_publishing'] = 						"publishing";//breadcrumb
?>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/language/1/am_default/my_publishing.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_publish_blog_item'] = 				"Published journals";
$lang['hdr_publish_forum'] =		 			"Published discussion posts";
$lang['hdr_poll_participation'] = 				"Poll participation";
$lang['hdr_publish_library'] = 					"Published library documents";
$lang['hdr_publish_shouts'] = 					"Published shouts";


//ERRORS
$lang['err_no_blogs'] = 						"Sorry, you have no blog contents.";
$lang['err_no_library'] = 						"Sorry, you have no library documents.";
$lang['err_no_poll_participation'] =			"Sorry, you have not voted.";
$lang['err_no_shouts'] = 						"Sorry, no shouts.";
$lang['err_no_forum'] = 						"Sorry, you have no discussion posts.";


//BODY
$lang['txt_publishing'] = 						"publishing";//breadcrumb
?>
